@@ -51,6 +51,8 @@ class Config(object):
         self.action_list_profiles = False
         self.action_list_roles = False
         self.action_store_json_creds = False
+        self.action_setup_fido_authenticator = False
+        self.action_output_format = False
         self.output_format = 'export'
         self.roles = []
 
@@ -139,6 +141,10 @@ class Config(object):
         parser.add_argument(
             '--action-store-json-creds', action='store_true',
             help='Read credentials from stdin (in json format) and store them in ~/.aws/credentials file')
+        parser.add_argument(
+            '--action-setup-fido-authenticator', action='store_true',
+            help='Sets up a new FIDO WebAuthn authenticator in Okta'
+        )
         args = parser.parse_args(self.ui.args)
 
         self.action_configure = args.action_configure
@@ -146,6 +152,7 @@ class Config(object):
         self.action_list_roles = args.action_list_roles
         self.action_store_json_creds = args.action_store_json_creds
         self.action_register_device = args.action_register_device
+        self.action_setup_fido_authenticator = args.action_setup_fido_authenticator
 
         if args.insecure is True:
             ui.default.warning("Warning: SSL certificate validation is disabled!")
@@ -162,6 +169,7 @@ class Config(object):
         if args.resolve is True:
             self.resolve = True
         if args.output_format is not None:
+            self.action_output_format = args.output_format
             self.output_format = args.output_format
         if args.roles is not None:
             self.roles = [role.strip() for role in args.roles.split(',') if role.strip()]
@@ -169,7 +177,7 @@ class Config(object):
 
     def _handle_config(self, config, profile_config, include_inherits = True):
         if "inherits" in profile_config.keys() and include_inherits:
-            print("Using inherited config: " + profile_config["inherits"])
+            self.ui.message("Using inherited config: " + profile_config["inherits"])
             if profile_config["inherits"] not in config:
                 raise errors.GimmeAWSCredsError(self.conf_profile + " inherits from " + profile_config["inherits"] + ", but could not find " + profile_config["inherits"])
             combined_config = {
@@ -191,8 +199,11 @@ class Config(object):
 
             try:
                 profile_config = dict(config[self.conf_profile])
+                self.fail_if_profile_not_found(profile_config, self.conf_profile, config.default_section)
                 return self._handle_config(config, profile_config, include_inherits)
             except KeyError:
+                if self.action_configure:
+                    return {}
                 raise errors.GimmeAWSCredsError(
                     'Configuration profile not found! Use the --action-configure flag to generate the profile.')
         raise errors.GimmeAWSCredsError('Configuration file not found! Use the --action-configure flag to generate file.')
@@ -272,7 +283,9 @@ class Config(object):
         config_dict['aws_default_duration'] = self._get_aws_default_duration(defaults['aws_default_duration'])
         config_dict['preferred_mfa_type'] = self._get_preferred_mfa_type(defaults['preferred_mfa_type'])
         config_dict['remember_device'] = self._get_remember_device(defaults['remember_device'])
-        config_dict['output_format'] = self._get_output_format(defaults['output_format'])
+        config_dict["output_format"] = ''
+        if not config_dict["write_aws_creds"]:
+            config_dict['output_format'] = self._get_output_format(defaults['output_format'])
 
         # If write_aws_creds is True get the profile name
         if config_dict['write_aws_creds'] is True:
@@ -555,3 +568,14 @@ class Config(object):
         """ clean up secret stuff"""
         del self.username
         del self.api_key
+
+    def fail_if_profile_not_found(self, profile_config, conf_profile, default_section):
+        """
+        When a users profile does not have a profile named 'DEFAULT' configparser fails to throw
+        an exception. This will raise an exception that handles this case and provide better messaging
+        to the user why the failure occurred.
+        Ensure that whichever profile is set as the default exists in the end users okta config
+        """
+        if not profile_config and conf_profile == default_section:
+            raise errors.GimmeAWSCredsError(
+                'DEFAULT profile is missing! This is profile is required when not using --profile')
\ No newline at end of file
